# SPDX-FileCopyrightText: 2018-2022 Bruce Cowan <bruce@bcowan.me.uk>
#
# SPDX-License-Identifier: LGPL-3.0-or-later

from gi.repository import GLib, GObject, Gtk


@Gtk.Template(resource_path="/uk/me/bcowan/Countdown/ui/countdown-label.ui")
class CountdownLabel(Gtk.Box):
    """A label that displays a countdown to a specific time"""

    __gtype_name__ = "CountdownLabel"

    _time_label = Gtk.Template.Child()

    def __init__(self):
        super().__init__()

        # Properties
        self._target = GLib.DateTime.new_now_local()

        self._update_clock()
        GLib.timeout_add_seconds(1, self._update_clock)

    def _update_clock(self) -> bool:
        now = GLib.DateTime.new_now_local()
        diff = self._target.difference(now)

        self._time_label.props.label = self._format_difference(diff)
        return True

    @staticmethod
    def _format_difference(diff: int) -> str:
        diff = (abs(diff) / GLib.TIME_SPAN_SECOND) + 1
        seconds = int(diff % 60)
        diff /= 60
        minutes = int(diff % 60)
        diff /= 60
        hours = int(diff % 24)
        diff /= 24
        days = int(diff)

        return f"{days}\n{hours}\n{minutes}\n{seconds}"

    @GObject.Property(type=GLib.DateTime)
    def target(self) -> GLib.DateTime:
        return self._target

    @target.setter
    def target(self, target: GLib.DateTime) -> None:
        self._target = target
        self._update_clock()
