# SPDX-FileCopyrightText: 2018-2022 Bruce Cowan <bruce@bcowan.me.uk>
#
# SPDX-License-Identifier: LGPL-3.0-or-later

from __future__ import annotations

import sys

from gi.repository import Adw, Gio, GLib, Gtk

from countdown import applicationwindow


class Application(Adw.Application):
    def __init__(self) -> None:
        super().__init__(application_id="uk.me.bcowan.Countdown")

    def do_activate(self) -> None:
        win = self.props.active_window
        if not win:
            win = applicationwindow.ApplicationWindow(self)

        win.show()

    def do_startup(self) -> None:
        Adw.Application.do_startup(self)

        about_action = Gio.SimpleAction(name="about")
        about_action.connect("activate", self._on_about)
        self.add_action(about_action)

    def _on_about(self, action: Gio.SimpleAction, param: GLib.Variant | None) -> None:
        builder = Gtk.Builder.new_from_resource("/uk/me/bcowan/Countdown/ui/about.ui")
        win = builder.get_object("aboutwindow")
        win.props.transient_for = self.props.active_window
        win.present()


def main():
    app = Application()
    return app.run(sys.argv)
