# SPDX-FileCopyrightText: 2020-2022 Bruce Cowan <bruce@bcowan.me.uk>
#
# SPDX-License-Identifier: LGPL-3.0-or-later

from gi.repository import GLib, GObject, Gtk


@Gtk.Template(resource_path="/uk/me/bcowan/Countdown/ui/time-popover.ui")
class TimePopover(Gtk.Popover):
    __gtype_name__ = "TimePopover"

    _calendar = Gtk.Template.Child()
    _hours_spin = Gtk.Template.Child()
    _minutes_spin = Gtk.Template.Child()
    _seconds_spin = Gtk.Template.Child()

    def __init__(self):
        super().__init__()

        self._datetime = GLib.DateTime.new_now_local()
        self._display_datetime(self._datetime)

    @Gtk.Template.Callback()
    def _on_spin_output(self, spin: Gtk.SpinButton) -> bool:
        spin.props.text = f"{int(spin.props.value):02d}"
        return True

    @Gtk.Template.Callback()
    def _on_time_apply_clicked(self, btn: Gtk.Button) -> None:
        calendar_date = self._calendar.get_date()
        self._datetime = GLib.DateTime.new_local(
            *calendar_date.get_ymd(),
            int(self._hours_spin.props.value),
            int(self._minutes_spin.props.value),
            int(self._seconds_spin.props.value),
        )

        self.notify("datetime")
        self.popdown()

    def _display_datetime(self, datetime: GLib.DateTime) -> None:
        year, month, day = datetime.get_ymd()
        self._calendar.select_day(datetime)

        self._hours_spin.props.value = datetime.get_hour()
        self._minutes_spin.props.value = datetime.get_minute()
        self._seconds_spin.props.value = datetime.get_second()

    @GObject.Property(type=GLib.DateTime)
    def datetime(self) -> GLib.DateTime:
        return self._datetime

    @datetime.setter
    def datetime(self, value: GLib.DateTime):
        self._datetime = value
        self._display_datetime(value)
